summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/ascharanchoredobjectposition.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/inc/ascharanchoredobjectposition.hxx')
-rw-r--r--sw/source/core/inc/ascharanchoredobjectposition.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sw/source/core/inc/ascharanchoredobjectposition.hxx b/sw/source/core/inc/ascharanchoredobjectposition.hxx
index b346908ab86d..1a2fb9e70bef 100644
--- a/sw/source/core/inc/ascharanchoredobjectposition.hxx
+++ b/sw/source/core/inc/ascharanchoredobjectposition.hxx
@@ -25,7 +25,7 @@
#include <swtypes.hxx>
#include <swrect.hxx>
-class SwTextFrm;
+class SwTextFrame;
class SwFormatVertOrient;
namespace objectpositioning
@@ -69,8 +69,8 @@ namespace objectpositioning
// 0 - no line alignment, 1 - at top, 2 - at center, 3 - at bottom
sal_uInt8 mnLineAlignment;
- // method to cast <SwAnchoredObjectPosition::GetAnchorFrm()>
- const SwTextFrm& GetAnchorTextFrm() const;
+ // method to cast <SwAnchoredObjectPosition::GetAnchorFrame()>
+ const SwTextFrame& GetAnchorTextFrame() const;
/** determine the relative position to base line for object position